/*
 * Script for fixing 'stuck' archive status on clips/jobs which were last updated within the specified date range
 *
 * Updates status to failed for any jobs / clip archive metadata which are set to queued / running / waiting
 * and were last updated within the specified date range. Note this does not update the source media 'archiveStatus',
 * so any calculated fields based on that will not update until the clips have been re-submitted.
 *
 * Set the three variables at the top of the script as required. The narrower the date range, the better.
 *
 * NB this script needs to create/drop a temporary table to hold source media IDs, so it will fail if the user
 *    running the script does not have the permissions to do this.
 */

-- Set to Archiware, AmazonS3, Azure, BackBlaze, BlackPearl, MatrixStore, NearlineBackup as required
set @serviceType = 'EDIT THIS';
-- Set date range as required, the narrower the date range, the better
set @dateFrom = '2020-03-27 00:00:00';
set @dateTo = '2020-03-28 00:00:00';

set @unixDateFrom = UNIX_TIMESTAMP(@dateFrom);
set @unixDateTo = UNIX_TIMESTAMP(@dateTo);
set @unixDateFromMillis = @unixDateFrom * 1000;
set @unixDateToMillis = @unixDateTo * 1000;

select id into @statusFieldID from fieldDefinition where identifier = CONCAT('squarebox.catdv.archive.', @serviceType ,'.status');
select id into @dateFieldID from fieldDefinition where identifier = CONCAT('squarebox.catdv.archive.', @serviceType ,'.date');

create table tempUpdatedInRangeSMIDs (id int not null);

insert into tempUpdatedInRangeSMIDs
    select sourceMediaID from sourceMediaField
    where fieldDefID = @dateFieldID
      and UNIX_TIMESTAMP(value) >= @unixDateFrom and UNIX_TIMESTAMP(value) < @unixDateTo;

update job set statusCode = 5, status = CONCAT(jobType, ' failed')
where serviceType = @serviceType
  and (statusCode = 1 or statusCode = 2 or statusCode = 3)
  and lastModifiedDate >= @unixDateFromMillis and lastModifiedDate < @unixDateToMillis;

update sourceMediaField set value = REPLACE(value, 'queued', 'failed')
where fieldDefID = @statusFieldID
  and value like '%queued%'
  and sourceMediaID in (select id from tempUpdatedInRangeSMIDs);

update sourceMediaField set value = REPLACE(value, 'running', 'failed')
where fieldDefID = @statusFieldID
  and value like '%running%'
  and sourceMediaID in (select id from tempUpdatedInRangeSMIDs);

update sourceMediaField set value = REPLACE(value, 'waiting', 'failed')
where fieldDefID = @statusFieldID
  and value like '%waiting%'
  and sourceMediaID in (select id from tempUpdatedInRangeSMIDs);

drop table tempUpdatedInRangeSMIDs;
